#
# spec file for package golang
#
# Copyright (c) 2015-2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%global provider        github
%global provider_tld    com
%global project         nsf
%global repo            gocode
%global provider_prefix %{provider}.%{provider_tld}/%{project}/%{repo}
%global import_path     %{provider_prefix}

Name:           golang-%{provider}-%{project}-%{repo}
Version:        0.0.0+git20161123.5070dac
Release:        bp153.1.65
Summary:        An autocompletion daemon for the Go programming language
License:        MIT
Group:          Development/Languages/Golang
Url:            https://%{provider_prefix}
Source0:        %{repo}-%{version}.tar.xz
Source1:        %{name}-rpmlintrc
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

BuildRequires:  golang-packaging
BuildRequires:  xz

BuildRequires:  vim
BuildRequires:  emacs-nox

%{go_nostrip}
%{go_provides}

%description
Gocode is a helper tool which is intended to be integrated with your
source code editor such as vim or emacs. It uses a client-server
architecture for caching purposes (hence "daemon") and provides
context-sensitive autocompletion.

%package -n gocode
Summary:        An autocompletion daemon for the Go programming language
Group:          Development/Languages/Golang
AutoReqProv:    Off

%{go_exclusivearch}

%description -n gocode
Gocode is a helper tool which is intended to be integrated with your
source code editor such as vim or emacs. It uses a client-server
architecture for caching purposes (hence "daemon") and provides
context-sensitive autocompletion.

%package -n vim-completion-golang
Summary:        Golang autocompletion files for Vim
Group:          Productivity/Text/Editors
AutoReqProv:    Off
Requires:       gocode = %{version}
Requires:       vim
Provides:	      vim-plugin-gocode = %{version}

%description -n vim-completion-golang
Vim autocompletion for the Go programming language.

%package -n emacs-completion-golang
Summary:	      Golang autocompletion files for Emacs
Group:		      Productivity/Text/Editors
AutoReqProv:    Off
Requires:	      gocode = %{version}
Requires:	      emacs

%description -n emacs-completion-golang
Emacs autocompletion for the Go programming language.

Add the following to your emacs-config:

```lisp
(require 'go-autocomplete)	; load go autocompletion backend
```

%prep
%setup -q -n %{repo}-%{version}

%build
%goprep %{import_path}
%gobuild ...

%install
%goinstall
%gosrc
%gofilelist

# vim-completion-golang
mkdir -p %{buildroot}%{_datadir}/vim/site/autoload/
install -Dm644 %{_builddir}/gocode-%{version}/vim/autoload/gocomplete.vim \
  %{buildroot}%{_datadir}/vim/site/autoload/gocomplete.vim
install -Dm644 %{_builddir}/gocode-%{version}/vim/ftplugin/go/gocomplete.vim \
  %{buildroot}%{_datadir}/vim/site/ftplugin/go/gocomplete.vim

# emacs-completion-golang
mkdir -p %{buildroot}%{_datadir}/emacs/site-lisp/
install -m 0644 %{_builddir}/gocode-%{version}/emacs/go-autocomplete.el \
  %{buildroot}%{_datadir}/emacs/site-lisp/

%check
%gotest %{import_path}...

%files -f file.lst
%defattr(-,root,root,-)
%doc README.md LICENSE

%files -n gocode
%defattr(-,root,root)
%{_bindir}/gocode

%files -n vim-completion-golang
%defattr(-,root,root,-)
%{_datadir}/vim/site/autoload/gocomplete.vim
%dir %{_datadir}/vim/site/ftplugin
%dir %{_datadir}/vim/site/ftplugin/go
%{_datadir}/vim/site/ftplugin/go/gocomplete.vim

%files -n emacs-completion-golang
%defattr(-,root,root,-)
%{_datadir}/emacs/site-lisp/go-autocomplete.el

%changelog
* Tue Jul  4 2017 jengelh@inai.de
- Trim description, don't sell standard speeds as "fast".
* Mon Dec 19 2016 tboerger@suse.com
- Update to version 0.0.0+git20161123.5070dac:
  * package_bin: backport compiler exporter fix for golang/go#15514
  * Optionally import unimported packages before autocompletion.
  * package_bin: update to match latest changes to std lib gcimporter
  * package_bin: update to recognize export format version 2
  * added pre go.17 hack
  * Rewrite package resolving code. Fixes #373.
  * emacs-company: make additional gocode arguments customisable
  * Fixes autocomplete paths for vendored packages
  * package_bin: read v3 export data not containing type aliases
  * Fixed a typing mistake
* Mon Dec 19 2016 tboerger@suse.com
- Refactoring based on new packaging proposal
* Sun Apr  3 2016 i@marguerite.su
- add xz dependency for SLE
- get rid of -source subpackage, no one use it
* Wed Jul 22 2015 i@marguerite.su
- rename to golang-github-nsf-gocode
- update version 20150303+git20150718.adab99b
- use golang-packaging for packaging
- add new subpackages:
  * emacs-completion-golang
  * emacs-completion-golang-company
  * vim-completion-golang (former go-gocode-vim)
* Sat Sep 20 2014 i@marguerite.su
- update version weekly2012.03.13+git20140903.8037a27
* Sun Dec  8 2013 graham@andtech.eu
- Update to latest git 08/10/2013
* Tue Aug 13 2013 speilicke@suse.com
- Use %%{go_exclusivearch} macro
* Wed May 15 2013 graham@andtech.eu
- Update to latest git @ 15.05.2013
- Fix infinite recursion bug in certain situations
- Improvements for emacs
- Remove bashism's in favour of POSIX shell syntax
- Support multibyte charsets
* Wed Mar 20 2013 graham@andtech.eu
- update to git 2013.03.18
* Mon Mar  5 2012 graham@andtech.eu
- update for weekly.2012-03-04
* Sat Feb  4 2012 graham@andtech.eu
- tweak spec for new go tool layout
* Fri Feb  3 2012 graham@andtech.eu
- gofixes to build with new macros and tool
* Tue Oct 18 2011 saschpe@suse.de
- Initial version
